# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/dataproductversion/v1/dataproductversion.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/dataproductversion/v1/dataproductversion.proto',
  package='github.com.metaprov.modelaapi.services.dataproductversion.v1',
  syntax='proto3',
  serialized_options=b'Z<github.com/metaprov/modelaapi/services/dataproductversion/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nUgithub.com/metaprov/modelaapi/services/dataproductversion/v1/dataproductversion.proto\x12<github.com.metaprov.modelaapi.services.dataproductversion.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\"\xdc\x01\n\x1eListDataProductVersionsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12x\n\x06labels\x18\x03 \x03(\x0b\x32h.github.com.metaprov.modelaapi.services.dataproductversion.v1.ListDataProductVersionsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"~\n\x1fListDataProductVersionsResponse\x12[\n\x05items\x18\x01 \x01(\x0b\x32L.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersionList\"y\n\x1f\x43reateDataProductVersionRequest\x12V\n\x04item\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\"\"\n CreateDataProductVersionResponse\"y\n\x1fUpdateDataProductVersionRequest\x12V\n\x04item\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\"\"\n UpdateDataProductVersionResponse\"?\n\x1cGetDataProductVersionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x85\x01\n\x1dGetDataProductVersionResponse\x12V\n\x04item\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"B\n\x1f\x44\x65leteDataProductVersionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\"\n DeleteDataProductVersionResponse2\xc7\n\n\x19\x44\x61taProductVersionService\x12\xf7\x01\n\x17ListDataProductVersions\x12\\.github.com.metaprov.modelaapi.services.dataproductversion.v1.ListDataProductVersionsRequest\x1a].github.com.metaprov.modelaapi.services.dataproductversion.v1.ListDataProductVersionsResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/dataproductversions\x12\xfd\x01\n\x18\x43reateDataProductVersion\x12].github.com.metaprov.modelaapi.services.dataproductversion.v1.CreateDataProductVersionRequest\x1a^.github.com.metaprov.modelaapi.services.dataproductversion.v1.CreateDataProductVersionResponse\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/v1/dataproductversions:\x01*\x12\xf8\x01\n\x15GetDataProductVersion\x12Z.github.com.metaprov.modelaapi.services.dataproductversion.v1.GetDataProductVersionRequest\x1a[.github.com.metaprov.modelaapi.services.dataproductversion.v1.GetDataProductVersionResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/v1/dataproductversions/{name}\x12\xa0\x02\n\x18UpdateDataProductVersion\x12].github.com.metaprov.modelaapi.services.dataproductversion.v1.UpdateDataProductVersionRequest\x1a^.github.com.metaprov.modelaapi.services.dataproductversion.v1.UpdateDataProductVersionResponse\"E\x82\xd3\xe4\x93\x02?\x1a:/v1/dataproductversions/{dataproductversion.metadata.name}:\x01*\x12\x91\x02\n\x18\x44\x65leteDataProductVersion\x12].github.com.metaprov.modelaapi.services.dataproductversion.v1.DeleteDataProductVersionRequest\x1a^.github.com.metaprov.modelaapi.services.dataproductversion.v1.DeleteDataProductVersionResponse\"6\x82\xd3\xe4\x93\x02\x30*./api/v1/dataproductversions/{namespace}/{name}B>Z<github.com/metaprov/modelaapi/services/dataproductversion/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2.DESCRIPTOR,])




_LISTDATAPRODUCTVERSIONSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.dataproductversion.v1.ListDataProductVersionsRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.dataproductversion.v1.ListDataProductVersionsRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.dataproductversion.v1.ListDataProductVersionsRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=490,
  serialized_end=535,
)

_LISTDATAPRODUCTVERSIONSREQUEST = _descriptor.Descriptor(
  name='ListDataProductVersionsRequest',
  full_name='github.com.metaprov.modelaapi.services.dataproductversion.v1.ListDataProductVersionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dataproductversion.v1.ListDataProductVersionsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.dataproductversion.v1.ListDataProductVersionsRequest.labels', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTDATAPRODUCTVERSIONSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=315,
  serialized_end=535,
)


_LISTDATAPRODUCTVERSIONSRESPONSE = _descriptor.Descriptor(
  name='ListDataProductVersionsResponse',
  full_name='github.com.metaprov.modelaapi.services.dataproductversion.v1.ListDataProductVersionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dataproductversion.v1.ListDataProductVersionsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=537,
  serialized_end=663,
)


_CREATEDATAPRODUCTVERSIONREQUEST = _descriptor.Descriptor(
  name='CreateDataProductVersionRequest',
  full_name='github.com.metaprov.modelaapi.services.dataproductversion.v1.CreateDataProductVersionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dataproductversion.v1.CreateDataProductVersionRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=665,
  serialized_end=786,
)


_CREATEDATAPRODUCTVERSIONRESPONSE = _descriptor.Descriptor(
  name='CreateDataProductVersionResponse',
  full_name='github.com.metaprov.modelaapi.services.dataproductversion.v1.CreateDataProductVersionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=788,
  serialized_end=822,
)


_UPDATEDATAPRODUCTVERSIONREQUEST = _descriptor.Descriptor(
  name='UpdateDataProductVersionRequest',
  full_name='github.com.metaprov.modelaapi.services.dataproductversion.v1.UpdateDataProductVersionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dataproductversion.v1.UpdateDataProductVersionRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=824,
  serialized_end=945,
)


_UPDATEDATAPRODUCTVERSIONRESPONSE = _descriptor.Descriptor(
  name='UpdateDataProductVersionResponse',
  full_name='github.com.metaprov.modelaapi.services.dataproductversion.v1.UpdateDataProductVersionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=947,
  serialized_end=981,
)


_GETDATAPRODUCTVERSIONREQUEST = _descriptor.Descriptor(
  name='GetDataProductVersionRequest',
  full_name='github.com.metaprov.modelaapi.services.dataproductversion.v1.GetDataProductVersionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dataproductversion.v1.GetDataProductVersionRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dataproductversion.v1.GetDataProductVersionRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=983,
  serialized_end=1046,
)


_GETDATAPRODUCTVERSIONRESPONSE = _descriptor.Descriptor(
  name='GetDataProductVersionResponse',
  full_name='github.com.metaprov.modelaapi.services.dataproductversion.v1.GetDataProductVersionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dataproductversion.v1.GetDataProductVersionResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.dataproductversion.v1.GetDataProductVersionResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1049,
  serialized_end=1182,
)


_DELETEDATAPRODUCTVERSIONREQUEST = _descriptor.Descriptor(
  name='DeleteDataProductVersionRequest',
  full_name='github.com.metaprov.modelaapi.services.dataproductversion.v1.DeleteDataProductVersionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dataproductversion.v1.DeleteDataProductVersionRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dataproductversion.v1.DeleteDataProductVersionRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1184,
  serialized_end=1250,
)


_DELETEDATAPRODUCTVERSIONRESPONSE = _descriptor.Descriptor(
  name='DeleteDataProductVersionResponse',
  full_name='github.com.metaprov.modelaapi.services.dataproductversion.v1.DeleteDataProductVersionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1252,
  serialized_end=1286,
)

_LISTDATAPRODUCTVERSIONSREQUEST_LABELSENTRY.containing_type = _LISTDATAPRODUCTVERSIONSREQUEST
_LISTDATAPRODUCTVERSIONSREQUEST.fields_by_name['labels'].message_type = _LISTDATAPRODUCTVERSIONSREQUEST_LABELSENTRY
_LISTDATAPRODUCTVERSIONSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCTVERSIONLIST
_CREATEDATAPRODUCTVERSIONREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCTVERSION
_UPDATEDATAPRODUCTVERSIONREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCTVERSION
_GETDATAPRODUCTVERSIONRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCTVERSION
DESCRIPTOR.message_types_by_name['ListDataProductVersionsRequest'] = _LISTDATAPRODUCTVERSIONSREQUEST
DESCRIPTOR.message_types_by_name['ListDataProductVersionsResponse'] = _LISTDATAPRODUCTVERSIONSRESPONSE
DESCRIPTOR.message_types_by_name['CreateDataProductVersionRequest'] = _CREATEDATAPRODUCTVERSIONREQUEST
DESCRIPTOR.message_types_by_name['CreateDataProductVersionResponse'] = _CREATEDATAPRODUCTVERSIONRESPONSE
DESCRIPTOR.message_types_by_name['UpdateDataProductVersionRequest'] = _UPDATEDATAPRODUCTVERSIONREQUEST
DESCRIPTOR.message_types_by_name['UpdateDataProductVersionResponse'] = _UPDATEDATAPRODUCTVERSIONRESPONSE
DESCRIPTOR.message_types_by_name['GetDataProductVersionRequest'] = _GETDATAPRODUCTVERSIONREQUEST
DESCRIPTOR.message_types_by_name['GetDataProductVersionResponse'] = _GETDATAPRODUCTVERSIONRESPONSE
DESCRIPTOR.message_types_by_name['DeleteDataProductVersionRequest'] = _DELETEDATAPRODUCTVERSIONREQUEST
DESCRIPTOR.message_types_by_name['DeleteDataProductVersionResponse'] = _DELETEDATAPRODUCTVERSIONRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListDataProductVersionsRequest = _reflection.GeneratedProtocolMessageType('ListDataProductVersionsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTDATAPRODUCTVERSIONSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.dataproductversion.v1.dataproductversion_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataproductversion.v1.ListDataProductVersionsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTDATAPRODUCTVERSIONSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataproductversion.v1.dataproductversion_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataproductversion.v1.ListDataProductVersionsRequest)
  })
_sym_db.RegisterMessage(ListDataProductVersionsRequest)
_sym_db.RegisterMessage(ListDataProductVersionsRequest.LabelsEntry)

ListDataProductVersionsResponse = _reflection.GeneratedProtocolMessageType('ListDataProductVersionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATAPRODUCTVERSIONSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataproductversion.v1.dataproductversion_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataproductversion.v1.ListDataProductVersionsResponse)
  })
_sym_db.RegisterMessage(ListDataProductVersionsResponse)

CreateDataProductVersionRequest = _reflection.GeneratedProtocolMessageType('CreateDataProductVersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAPRODUCTVERSIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataproductversion.v1.dataproductversion_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataproductversion.v1.CreateDataProductVersionRequest)
  })
_sym_db.RegisterMessage(CreateDataProductVersionRequest)

CreateDataProductVersionResponse = _reflection.GeneratedProtocolMessageType('CreateDataProductVersionResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAPRODUCTVERSIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataproductversion.v1.dataproductversion_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataproductversion.v1.CreateDataProductVersionResponse)
  })
_sym_db.RegisterMessage(CreateDataProductVersionResponse)

UpdateDataProductVersionRequest = _reflection.GeneratedProtocolMessageType('UpdateDataProductVersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAPRODUCTVERSIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataproductversion.v1.dataproductversion_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataproductversion.v1.UpdateDataProductVersionRequest)
  })
_sym_db.RegisterMessage(UpdateDataProductVersionRequest)

UpdateDataProductVersionResponse = _reflection.GeneratedProtocolMessageType('UpdateDataProductVersionResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAPRODUCTVERSIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataproductversion.v1.dataproductversion_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataproductversion.v1.UpdateDataProductVersionResponse)
  })
_sym_db.RegisterMessage(UpdateDataProductVersionResponse)

GetDataProductVersionRequest = _reflection.GeneratedProtocolMessageType('GetDataProductVersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATAPRODUCTVERSIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataproductversion.v1.dataproductversion_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataproductversion.v1.GetDataProductVersionRequest)
  })
_sym_db.RegisterMessage(GetDataProductVersionRequest)

GetDataProductVersionResponse = _reflection.GeneratedProtocolMessageType('GetDataProductVersionResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDATAPRODUCTVERSIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataproductversion.v1.dataproductversion_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataproductversion.v1.GetDataProductVersionResponse)
  })
_sym_db.RegisterMessage(GetDataProductVersionResponse)

DeleteDataProductVersionRequest = _reflection.GeneratedProtocolMessageType('DeleteDataProductVersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATAPRODUCTVERSIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataproductversion.v1.dataproductversion_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataproductversion.v1.DeleteDataProductVersionRequest)
  })
_sym_db.RegisterMessage(DeleteDataProductVersionRequest)

DeleteDataProductVersionResponse = _reflection.GeneratedProtocolMessageType('DeleteDataProductVersionResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATAPRODUCTVERSIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataproductversion.v1.dataproductversion_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataproductversion.v1.DeleteDataProductVersionResponse)
  })
_sym_db.RegisterMessage(DeleteDataProductVersionResponse)


DESCRIPTOR._options = None
_LISTDATAPRODUCTVERSIONSREQUEST_LABELSENTRY._options = None

_DATAPRODUCTVERSIONSERVICE = _descriptor.ServiceDescriptor(
  name='DataProductVersionService',
  full_name='github.com.metaprov.modelaapi.services.dataproductversion.v1.DataProductVersionService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1289,
  serialized_end=2640,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListDataProductVersions',
    full_name='github.com.metaprov.modelaapi.services.dataproductversion.v1.DataProductVersionService.ListDataProductVersions',
    index=0,
    containing_service=None,
    input_type=_LISTDATAPRODUCTVERSIONSREQUEST,
    output_type=_LISTDATAPRODUCTVERSIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002\031\022\027/v1/dataproductversions',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateDataProductVersion',
    full_name='github.com.metaprov.modelaapi.services.dataproductversion.v1.DataProductVersionService.CreateDataProductVersion',
    index=1,
    containing_service=None,
    input_type=_CREATEDATAPRODUCTVERSIONREQUEST,
    output_type=_CREATEDATAPRODUCTVERSIONRESPONSE,
    serialized_options=b'\202\323\344\223\002\034\"\027/v1/dataproductversions:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDataProductVersion',
    full_name='github.com.metaprov.modelaapi.services.dataproductversion.v1.DataProductVersionService.GetDataProductVersion',
    index=2,
    containing_service=None,
    input_type=_GETDATAPRODUCTVERSIONREQUEST,
    output_type=_GETDATAPRODUCTVERSIONRESPONSE,
    serialized_options=b'\202\323\344\223\002 \022\036/v1/dataproductversions/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateDataProductVersion',
    full_name='github.com.metaprov.modelaapi.services.dataproductversion.v1.DataProductVersionService.UpdateDataProductVersion',
    index=3,
    containing_service=None,
    input_type=_UPDATEDATAPRODUCTVERSIONREQUEST,
    output_type=_UPDATEDATAPRODUCTVERSIONRESPONSE,
    serialized_options=b'\202\323\344\223\002?\032:/v1/dataproductversions/{dataproductversion.metadata.name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteDataProductVersion',
    full_name='github.com.metaprov.modelaapi.services.dataproductversion.v1.DataProductVersionService.DeleteDataProductVersion',
    index=4,
    containing_service=None,
    input_type=_DELETEDATAPRODUCTVERSIONREQUEST,
    output_type=_DELETEDATAPRODUCTVERSIONRESPONSE,
    serialized_options=b'\202\323\344\223\0020*./api/v1/dataproductversions/{namespace}/{name}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DATAPRODUCTVERSIONSERVICE)

DESCRIPTOR.services_by_name['DataProductVersionService'] = _DATAPRODUCTVERSIONSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/servingsite/v1/servingsite.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/servingsite/v1/servingsite.proto',
  package='github.com.metaprov.modelaapi.services.servingsite.v1',
  syntax='proto3',
  serialized_options=b'Z5github.com/metaprov/modelaapi/services/servingsite/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nGgithub.com/metaprov/modelaapi/services/servingsite/v1/servingsite.proto\x12\x35github.com.metaprov.modelaapi.services.servingsite.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\"\xc7\x01\n\x17ListServingSitesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12j\n\x06labels\x18\x02 \x03(\x0b\x32Z.github.com.metaprov.modelaapi.services.servingsite.v1.ListServingSitesRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"q\n\x18ListServingSitesResponse\x12U\n\x05items\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ServingSiteList\"l\n\x18\x43reateServingSiteRequest\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ServingSite\"\x1b\n\x19\x43reateServingSiteResponse\"l\n\x18UpdateServingSiteRequest\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ServingSite\"\x1b\n\x19UpdateServingSiteResponse\"8\n\x15GetServingSiteRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"x\n\x16GetServingSiteResponse\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ServingSite\x12\x0c\n\x04yaml\x18\x02 \x01(\t\";\n\x18\x44\x65leteServingSiteRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1b\n\x19\x44\x65leteServingSiteResponse2\xec\x08\n\x12ServingSiteService\x12\xcd\x01\n\x10ListServingSites\x12N.github.com.metaprov.modelaapi.services.servingsite.v1.ListServingSitesRequest\x1aO.github.com.metaprov.modelaapi.services.servingsite.v1.ListServingSitesResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/v1/servingsites\x12\xd3\x01\n\x11\x43reateServingSite\x12O.github.com.metaprov.modelaapi.services.servingsite.v1.CreateServingSiteRequest\x1aP.github.com.metaprov.modelaapi.services.servingsite.v1.CreateServingSiteResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x10/v1/servingsites:\x01*\x12\xce\x01\n\x0eGetServingSite\x12L.github.com.metaprov.modelaapi.services.servingsite.v1.GetServingSiteRequest\x1aM.github.com.metaprov.modelaapi.services.servingsite.v1.GetServingSiteResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/servingsites/{name}\x12\xef\x01\n\x11UpdateServingSite\x12O.github.com.metaprov.modelaapi.services.servingsite.v1.UpdateServingSiteRequest\x1aP.github.com.metaprov.modelaapi.services.servingsite.v1.UpdateServingSiteResponse\"7\x82\xd3\xe4\x93\x02\x31\x1a,/v1/servingsites/{servingsite.metadata.name}:\x01*\x12\xec\x01\n\x11\x44\x65leteServingSite\x12O.github.com.metaprov.modelaapi.services.servingsite.v1.DeleteServingSiteRequest\x1aP.github.com.metaprov.modelaapi.services.servingsite.v1.DeleteServingSiteResponse\"4\x82\xd3\xe4\x93\x02.*,/v1/servingsites/{servingsite.metadata.name}B7Z5github.com/metaprov/modelaapi/services/servingsite/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_LISTSERVINGSITESREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.servingsite.v1.ListServingSitesRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.servingsite.v1.ListServingSitesRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.servingsite.v1.ListServingSitesRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=386,
  serialized_end=431,
)

_LISTSERVINGSITESREQUEST = _descriptor.Descriptor(
  name='ListServingSitesRequest',
  full_name='github.com.metaprov.modelaapi.services.servingsite.v1.ListServingSitesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.servingsite.v1.ListServingSitesRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.servingsite.v1.ListServingSitesRequest.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTSERVINGSITESREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=232,
  serialized_end=431,
)


_LISTSERVINGSITESRESPONSE = _descriptor.Descriptor(
  name='ListServingSitesResponse',
  full_name='github.com.metaprov.modelaapi.services.servingsite.v1.ListServingSitesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.servingsite.v1.ListServingSitesResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=433,
  serialized_end=546,
)


_CREATESERVINGSITEREQUEST = _descriptor.Descriptor(
  name='CreateServingSiteRequest',
  full_name='github.com.metaprov.modelaapi.services.servingsite.v1.CreateServingSiteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.servingsite.v1.CreateServingSiteRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=548,
  serialized_end=656,
)


_CREATESERVINGSITERESPONSE = _descriptor.Descriptor(
  name='CreateServingSiteResponse',
  full_name='github.com.metaprov.modelaapi.services.servingsite.v1.CreateServingSiteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=658,
  serialized_end=685,
)


_UPDATESERVINGSITEREQUEST = _descriptor.Descriptor(
  name='UpdateServingSiteRequest',
  full_name='github.com.metaprov.modelaapi.services.servingsite.v1.UpdateServingSiteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.servingsite.v1.UpdateServingSiteRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=687,
  serialized_end=795,
)


_UPDATESERVINGSITERESPONSE = _descriptor.Descriptor(
  name='UpdateServingSiteResponse',
  full_name='github.com.metaprov.modelaapi.services.servingsite.v1.UpdateServingSiteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=797,
  serialized_end=824,
)


_GETSERVINGSITEREQUEST = _descriptor.Descriptor(
  name='GetServingSiteRequest',
  full_name='github.com.metaprov.modelaapi.services.servingsite.v1.GetServingSiteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.servingsite.v1.GetServingSiteRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.servingsite.v1.GetServingSiteRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=826,
  serialized_end=882,
)


_GETSERVINGSITERESPONSE = _descriptor.Descriptor(
  name='GetServingSiteResponse',
  full_name='github.com.metaprov.modelaapi.services.servingsite.v1.GetServingSiteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.servingsite.v1.GetServingSiteResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.servingsite.v1.GetServingSiteResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=884,
  serialized_end=1004,
)


_DELETESERVINGSITEREQUEST = _descriptor.Descriptor(
  name='DeleteServingSiteRequest',
  full_name='github.com.metaprov.modelaapi.services.servingsite.v1.DeleteServingSiteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.servingsite.v1.DeleteServingSiteRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.servingsite.v1.DeleteServingSiteRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1006,
  serialized_end=1065,
)


_DELETESERVINGSITERESPONSE = _descriptor.Descriptor(
  name='DeleteServingSiteResponse',
  full_name='github.com.metaprov.modelaapi.services.servingsite.v1.DeleteServingSiteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1067,
  serialized_end=1094,
)

_LISTSERVINGSITESREQUEST_LABELSENTRY.containing_type = _LISTSERVINGSITESREQUEST
_LISTSERVINGSITESREQUEST.fields_by_name['labels'].message_type = _LISTSERVINGSITESREQUEST_LABELSENTRY
_LISTSERVINGSITESRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._SERVINGSITELIST
_CREATESERVINGSITEREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._SERVINGSITE
_UPDATESERVINGSITEREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._SERVINGSITE
_GETSERVINGSITERESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._SERVINGSITE
DESCRIPTOR.message_types_by_name['ListServingSitesRequest'] = _LISTSERVINGSITESREQUEST
DESCRIPTOR.message_types_by_name['ListServingSitesResponse'] = _LISTSERVINGSITESRESPONSE
DESCRIPTOR.message_types_by_name['CreateServingSiteRequest'] = _CREATESERVINGSITEREQUEST
DESCRIPTOR.message_types_by_name['CreateServingSiteResponse'] = _CREATESERVINGSITERESPONSE
DESCRIPTOR.message_types_by_name['UpdateServingSiteRequest'] = _UPDATESERVINGSITEREQUEST
DESCRIPTOR.message_types_by_name['UpdateServingSiteResponse'] = _UPDATESERVINGSITERESPONSE
DESCRIPTOR.message_types_by_name['GetServingSiteRequest'] = _GETSERVINGSITEREQUEST
DESCRIPTOR.message_types_by_name['GetServingSiteResponse'] = _GETSERVINGSITERESPONSE
DESCRIPTOR.message_types_by_name['DeleteServingSiteRequest'] = _DELETESERVINGSITEREQUEST
DESCRIPTOR.message_types_by_name['DeleteServingSiteResponse'] = _DELETESERVINGSITERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListServingSitesRequest = _reflection.GeneratedProtocolMessageType('ListServingSitesRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTSERVINGSITESREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.servingsite.v1.servingsite_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.servingsite.v1.ListServingSitesRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTSERVINGSITESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.servingsite.v1.servingsite_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.servingsite.v1.ListServingSitesRequest)
  })
_sym_db.RegisterMessage(ListServingSitesRequest)
_sym_db.RegisterMessage(ListServingSitesRequest.LabelsEntry)

ListServingSitesResponse = _reflection.GeneratedProtocolMessageType('ListServingSitesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSERVINGSITESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.servingsite.v1.servingsite_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.servingsite.v1.ListServingSitesResponse)
  })
_sym_db.RegisterMessage(ListServingSitesResponse)

CreateServingSiteRequest = _reflection.GeneratedProtocolMessageType('CreateServingSiteRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESERVINGSITEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.servingsite.v1.servingsite_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.servingsite.v1.CreateServingSiteRequest)
  })
_sym_db.RegisterMessage(CreateServingSiteRequest)

CreateServingSiteResponse = _reflection.GeneratedProtocolMessageType('CreateServingSiteResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATESERVINGSITERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.servingsite.v1.servingsite_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.servingsite.v1.CreateServingSiteResponse)
  })
_sym_db.RegisterMessage(CreateServingSiteResponse)

UpdateServingSiteRequest = _reflection.GeneratedProtocolMessageType('UpdateServingSiteRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESERVINGSITEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.servingsite.v1.servingsite_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.servingsite.v1.UpdateServingSiteRequest)
  })
_sym_db.RegisterMessage(UpdateServingSiteRequest)

UpdateServingSiteResponse = _reflection.GeneratedProtocolMessageType('UpdateServingSiteResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESERVINGSITERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.servingsite.v1.servingsite_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.servingsite.v1.UpdateServingSiteResponse)
  })
_sym_db.RegisterMessage(UpdateServingSiteResponse)

GetServingSiteRequest = _reflection.GeneratedProtocolMessageType('GetServingSiteRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVINGSITEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.servingsite.v1.servingsite_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.servingsite.v1.GetServingSiteRequest)
  })
_sym_db.RegisterMessage(GetServingSiteRequest)

GetServingSiteResponse = _reflection.GeneratedProtocolMessageType('GetServingSiteResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVINGSITERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.servingsite.v1.servingsite_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.servingsite.v1.GetServingSiteResponse)
  })
_sym_db.RegisterMessage(GetServingSiteResponse)

DeleteServingSiteRequest = _reflection.GeneratedProtocolMessageType('DeleteServingSiteRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETESERVINGSITEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.servingsite.v1.servingsite_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.servingsite.v1.DeleteServingSiteRequest)
  })
_sym_db.RegisterMessage(DeleteServingSiteRequest)

DeleteServingSiteResponse = _reflection.GeneratedProtocolMessageType('DeleteServingSiteResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETESERVINGSITERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.servingsite.v1.servingsite_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.servingsite.v1.DeleteServingSiteResponse)
  })
_sym_db.RegisterMessage(DeleteServingSiteResponse)


DESCRIPTOR._options = None
_LISTSERVINGSITESREQUEST_LABELSENTRY._options = None

_SERVINGSITESERVICE = _descriptor.ServiceDescriptor(
  name='ServingSiteService',
  full_name='github.com.metaprov.modelaapi.services.servingsite.v1.ServingSiteService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1097,
  serialized_end=2229,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListServingSites',
    full_name='github.com.metaprov.modelaapi.services.servingsite.v1.ServingSiteService.ListServingSites',
    index=0,
    containing_service=None,
    input_type=_LISTSERVINGSITESREQUEST,
    output_type=_LISTSERVINGSITESRESPONSE,
    serialized_options=b'\202\323\344\223\002\022\022\020/v1/servingsites',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateServingSite',
    full_name='github.com.metaprov.modelaapi.services.servingsite.v1.ServingSiteService.CreateServingSite',
    index=1,
    containing_service=None,
    input_type=_CREATESERVINGSITEREQUEST,
    output_type=_CREATESERVINGSITERESPONSE,
    serialized_options=b'\202\323\344\223\002\025\"\020/v1/servingsites:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetServingSite',
    full_name='github.com.metaprov.modelaapi.services.servingsite.v1.ServingSiteService.GetServingSite',
    index=2,
    containing_service=None,
    input_type=_GETSERVINGSITEREQUEST,
    output_type=_GETSERVINGSITERESPONSE,
    serialized_options=b'\202\323\344\223\002\031\022\027/v1/servingsites/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateServingSite',
    full_name='github.com.metaprov.modelaapi.services.servingsite.v1.ServingSiteService.UpdateServingSite',
    index=3,
    containing_service=None,
    input_type=_UPDATESERVINGSITEREQUEST,
    output_type=_UPDATESERVINGSITERESPONSE,
    serialized_options=b'\202\323\344\223\0021\032,/v1/servingsites/{servingsite.metadata.name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteServingSite',
    full_name='github.com.metaprov.modelaapi.services.servingsite.v1.ServingSiteService.DeleteServingSite',
    index=4,
    containing_service=None,
    input_type=_DELETESERVINGSITEREQUEST,
    output_type=_DELETESERVINGSITERESPONSE,
    serialized_options=b'\202\323\344\223\002.*,/v1/servingsites/{servingsite.metadata.name}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SERVINGSITESERVICE)

DESCRIPTOR.services_by_name['ServingSiteService'] = _SERVINGSITESERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/prediction/v1/prediction.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/prediction/v1/prediction.proto',
  package='github.com.metaprov.modelaapi.services.prediction.v1',
  syntax='proto3',
  serialized_options=b'Z4github.com/metaprov/modelaapi/services/prediction/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nEgithub.com/metaprov/modelaapi/services/prediction/v1/prediction.proto\x12\x34github.com.metaprov.modelaapi.services.prediction.v1\x1a\x1cgoogle/api/annotations.proto\x1aIgithub.com/metaprov/modelaapi/pkg/apis/inference/v1alpha1/generated.proto\"\xd2\x01\n\x16ListPredictionsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12h\n\x06labels\x18\x03 \x03(\x0b\x32X.github.com.metaprov.modelaapi.services.prediction.v1.ListPredictionsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"s\n\x17ListPredictionsResponse\x12X\n\x05items\x18\x01 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.PredictionList\"\x1a\n\x18\x43reatePredictionResponse\"n\n\x17\x43reatePredictionRequest\x12S\n\x04item\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Prediction\"n\n\x17UpdatePredictionRequest\x12S\n\x04item\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Prediction\"\x1a\n\x18UpdatePredictionResponse\"7\n\x14GetPredictionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"z\n\x15GetPredictionResponse\x12S\n\x04item\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Prediction\x12\x0c\n\x04yaml\x18\x02 \x01(\t\":\n\x17\x44\x65letePredictionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1a\n\x18\x44\x65letePredictionResponse\"<\n\x19\x44ownloadPredictionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\")\n\x1a\x44ownloadPredictionResponse\x12\x0b\n\x03raw\x18\x01 \x01(\x0c\"9\n\x16\x41\x62ortPredictionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x19\n\x17\x41\x62ortPredictionResponse2\xb4\x0c\n\x11PredictionService\x12\xc7\x01\n\x0fListPredictions\x12L.github.com.metaprov.modelaapi.services.prediction.v1.ListPredictionsRequest\x1aM.github.com.metaprov.modelaapi.services.prediction.v1.ListPredictionsResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/v1/predictions\x12\xcd\x01\n\x10\x43reatePrediction\x12M.github.com.metaprov.modelaapi.services.prediction.v1.CreatePredictionRequest\x1aN.github.com.metaprov.modelaapi.services.prediction.v1.CreatePredictionResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/predictions:\x01*\x12\xd4\x01\n\rGetPrediction\x12J.github.com.metaprov.modelaapi.services.prediction.v1.GetPredictionRequest\x1aK.github.com.metaprov.modelaapi.services.prediction.v1.GetPredictionResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/v1/{namespace}/predictions/{name}\x12\x87\x02\n\x10UpdatePrediction\x12M.github.com.metaprov.modelaapi.services.prediction.v1.UpdatePredictionRequest\x1aN.github.com.metaprov.modelaapi.services.prediction.v1.UpdatePredictionResponse\"T\x82\xd3\xe4\x93\x02N\x1aI/v1/{prediction.metadata.namespace}predictions/{prediction.metadata.name}:\x01*\x12\xd1\x01\n\x10\x44\x65letePrediction\x12M.github.com.metaprov.modelaapi.services.prediction.v1.DeletePredictionRequest\x1aN.github.com.metaprov.modelaapi.services.prediction.v1.DeletePredictionResponse\"\x1e\x82\xd3\xe4\x93\x02\x18*\x16/v1/predictions/{name}\x12\xec\x01\n\x08\x44ownload\x12O.github.com.metaprov.modelaapi.services.prediction.v1.DownloadPredictionRequest\x1aP.github.com.metaprov.modelaapi.services.prediction.v1.DownloadPredictionResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/api/v1alpha1/{namespace}/predictions/{name}:download\x12\xe0\x01\n\x05\x41\x62ort\x12L.github.com.metaprov.modelaapi.services.prediction.v1.AbortPredictionRequest\x1aM.github.com.metaprov.modelaapi.services.prediction.v1.AbortPredictionResponse\":\x82\xd3\xe4\x93\x02\x34\"2/api/v1alpha1/{namespace}/predictions/{name}:abortB6Z4github.com/metaprov/modelaapi/services/prediction/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_LISTPREDICTIONSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.prediction.v1.ListPredictionsRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.prediction.v1.ListPredictionsRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.prediction.v1.ListPredictionsRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=398,
  serialized_end=443,
)

_LISTPREDICTIONSREQUEST = _descriptor.Descriptor(
  name='ListPredictionsRequest',
  full_name='github.com.metaprov.modelaapi.services.prediction.v1.ListPredictionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.prediction.v1.ListPredictionsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.prediction.v1.ListPredictionsRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.prediction.v1.ListPredictionsRequest.labels', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTPREDICTIONSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=233,
  serialized_end=443,
)


_LISTPREDICTIONSRESPONSE = _descriptor.Descriptor(
  name='ListPredictionsResponse',
  full_name='github.com.metaprov.modelaapi.services.prediction.v1.ListPredictionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.prediction.v1.ListPredictionsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=445,
  serialized_end=560,
)


_CREATEPREDICTIONRESPONSE = _descriptor.Descriptor(
  name='CreatePredictionResponse',
  full_name='github.com.metaprov.modelaapi.services.prediction.v1.CreatePredictionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=562,
  serialized_end=588,
)


_CREATEPREDICTIONREQUEST = _descriptor.Descriptor(
  name='CreatePredictionRequest',
  full_name='github.com.metaprov.modelaapi.services.prediction.v1.CreatePredictionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.prediction.v1.CreatePredictionRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=590,
  serialized_end=700,
)


_UPDATEPREDICTIONREQUEST = _descriptor.Descriptor(
  name='UpdatePredictionRequest',
  full_name='github.com.metaprov.modelaapi.services.prediction.v1.UpdatePredictionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.prediction.v1.UpdatePredictionRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=702,
  serialized_end=812,
)


_UPDATEPREDICTIONRESPONSE = _descriptor.Descriptor(
  name='UpdatePredictionResponse',
  full_name='github.com.metaprov.modelaapi.services.prediction.v1.UpdatePredictionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=814,
  serialized_end=840,
)


_GETPREDICTIONREQUEST = _descriptor.Descriptor(
  name='GetPredictionRequest',
  full_name='github.com.metaprov.modelaapi.services.prediction.v1.GetPredictionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.prediction.v1.GetPredictionRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.prediction.v1.GetPredictionRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=842,
  serialized_end=897,
)


_GETPREDICTIONRESPONSE = _descriptor.Descriptor(
  name='GetPredictionResponse',
  full_name='github.com.metaprov.modelaapi.services.prediction.v1.GetPredictionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.prediction.v1.GetPredictionResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.prediction.v1.GetPredictionResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=899,
  serialized_end=1021,
)


_DELETEPREDICTIONREQUEST = _descriptor.Descriptor(
  name='DeletePredictionRequest',
  full_name='github.com.metaprov.modelaapi.services.prediction.v1.DeletePredictionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.prediction.v1.DeletePredictionRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.prediction.v1.DeletePredictionRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1023,
  serialized_end=1081,
)


_DELETEPREDICTIONRESPONSE = _descriptor.Descriptor(
  name='DeletePredictionResponse',
  full_name='github.com.metaprov.modelaapi.services.prediction.v1.DeletePredictionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1083,
  serialized_end=1109,
)


_DOWNLOADPREDICTIONREQUEST = _descriptor.Descriptor(
  name='DownloadPredictionRequest',
  full_name='github.com.metaprov.modelaapi.services.prediction.v1.DownloadPredictionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.prediction.v1.DownloadPredictionRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.prediction.v1.DownloadPredictionRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1111,
  serialized_end=1171,
)


_DOWNLOADPREDICTIONRESPONSE = _descriptor.Descriptor(
  name='DownloadPredictionResponse',
  full_name='github.com.metaprov.modelaapi.services.prediction.v1.DownloadPredictionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='raw', full_name='github.com.metaprov.modelaapi.services.prediction.v1.DownloadPredictionResponse.raw', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1173,
  serialized_end=1214,
)


_ABORTPREDICTIONREQUEST = _descriptor.Descriptor(
  name='AbortPredictionRequest',
  full_name='github.com.metaprov.modelaapi.services.prediction.v1.AbortPredictionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.prediction.v1.AbortPredictionRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.prediction.v1.AbortPredictionRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1216,
  serialized_end=1273,
)


_ABORTPREDICTIONRESPONSE = _descriptor.Descriptor(
  name='AbortPredictionResponse',
  full_name='github.com.metaprov.modelaapi.services.prediction.v1.AbortPredictionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1275,
  serialized_end=1300,
)

_LISTPREDICTIONSREQUEST_LABELSENTRY.containing_type = _LISTPREDICTIONSREQUEST
_LISTPREDICTIONSREQUEST.fields_by_name['labels'].message_type = _LISTPREDICTIONSREQUEST_LABELSENTRY
_LISTPREDICTIONSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._PREDICTIONLIST
_CREATEPREDICTIONREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._PREDICTION
_UPDATEPREDICTIONREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._PREDICTION
_GETPREDICTIONRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._PREDICTION
DESCRIPTOR.message_types_by_name['ListPredictionsRequest'] = _LISTPREDICTIONSREQUEST
DESCRIPTOR.message_types_by_name['ListPredictionsResponse'] = _LISTPREDICTIONSRESPONSE
DESCRIPTOR.message_types_by_name['CreatePredictionResponse'] = _CREATEPREDICTIONRESPONSE
DESCRIPTOR.message_types_by_name['CreatePredictionRequest'] = _CREATEPREDICTIONREQUEST
DESCRIPTOR.message_types_by_name['UpdatePredictionRequest'] = _UPDATEPREDICTIONREQUEST
DESCRIPTOR.message_types_by_name['UpdatePredictionResponse'] = _UPDATEPREDICTIONRESPONSE
DESCRIPTOR.message_types_by_name['GetPredictionRequest'] = _GETPREDICTIONREQUEST
DESCRIPTOR.message_types_by_name['GetPredictionResponse'] = _GETPREDICTIONRESPONSE
DESCRIPTOR.message_types_by_name['DeletePredictionRequest'] = _DELETEPREDICTIONREQUEST
DESCRIPTOR.message_types_by_name['DeletePredictionResponse'] = _DELETEPREDICTIONRESPONSE
DESCRIPTOR.message_types_by_name['DownloadPredictionRequest'] = _DOWNLOADPREDICTIONREQUEST
DESCRIPTOR.message_types_by_name['DownloadPredictionResponse'] = _DOWNLOADPREDICTIONRESPONSE
DESCRIPTOR.message_types_by_name['AbortPredictionRequest'] = _ABORTPREDICTIONREQUEST
DESCRIPTOR.message_types_by_name['AbortPredictionResponse'] = _ABORTPREDICTIONRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListPredictionsRequest = _reflection.GeneratedProtocolMessageType('ListPredictionsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTPREDICTIONSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.prediction.v1.prediction_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.prediction.v1.ListPredictionsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTPREDICTIONSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.prediction.v1.prediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.prediction.v1.ListPredictionsRequest)
  })
_sym_db.RegisterMessage(ListPredictionsRequest)
_sym_db.RegisterMessage(ListPredictionsRequest.LabelsEntry)

ListPredictionsResponse = _reflection.GeneratedProtocolMessageType('ListPredictionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPREDICTIONSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.prediction.v1.prediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.prediction.v1.ListPredictionsResponse)
  })
_sym_db.RegisterMessage(ListPredictionsResponse)

CreatePredictionResponse = _reflection.GeneratedProtocolMessageType('CreatePredictionResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPREDICTIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.prediction.v1.prediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.prediction.v1.CreatePredictionResponse)
  })
_sym_db.RegisterMessage(CreatePredictionResponse)

CreatePredictionRequest = _reflection.GeneratedProtocolMessageType('CreatePredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.prediction.v1.prediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.prediction.v1.CreatePredictionRequest)
  })
_sym_db.RegisterMessage(CreatePredictionRequest)

UpdatePredictionRequest = _reflection.GeneratedProtocolMessageType('UpdatePredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.prediction.v1.prediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.prediction.v1.UpdatePredictionRequest)
  })
_sym_db.RegisterMessage(UpdatePredictionRequest)

UpdatePredictionResponse = _reflection.GeneratedProtocolMessageType('UpdatePredictionResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPREDICTIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.prediction.v1.prediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.prediction.v1.UpdatePredictionResponse)
  })
_sym_db.RegisterMessage(UpdatePredictionResponse)

GetPredictionRequest = _reflection.GeneratedProtocolMessageType('GetPredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.prediction.v1.prediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.prediction.v1.GetPredictionRequest)
  })
_sym_db.RegisterMessage(GetPredictionRequest)

GetPredictionResponse = _reflection.GeneratedProtocolMessageType('GetPredictionResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETPREDICTIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.prediction.v1.prediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.prediction.v1.GetPredictionResponse)
  })
_sym_db.RegisterMessage(GetPredictionResponse)

DeletePredictionRequest = _reflection.GeneratedProtocolMessageType('DeletePredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.prediction.v1.prediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.prediction.v1.DeletePredictionRequest)
  })
_sym_db.RegisterMessage(DeletePredictionRequest)

DeletePredictionResponse = _reflection.GeneratedProtocolMessageType('DeletePredictionResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPREDICTIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.prediction.v1.prediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.prediction.v1.DeletePredictionResponse)
  })
_sym_db.RegisterMessage(DeletePredictionResponse)

DownloadPredictionRequest = _reflection.GeneratedProtocolMessageType('DownloadPredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.prediction.v1.prediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.prediction.v1.DownloadPredictionRequest)
  })
_sym_db.RegisterMessage(DownloadPredictionRequest)

DownloadPredictionResponse = _reflection.GeneratedProtocolMessageType('DownloadPredictionResponse', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADPREDICTIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.prediction.v1.prediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.prediction.v1.DownloadPredictionResponse)
  })
_sym_db.RegisterMessage(DownloadPredictionResponse)

AbortPredictionRequest = _reflection.GeneratedProtocolMessageType('AbortPredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _ABORTPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.prediction.v1.prediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.prediction.v1.AbortPredictionRequest)
  })
_sym_db.RegisterMessage(AbortPredictionRequest)

AbortPredictionResponse = _reflection.GeneratedProtocolMessageType('AbortPredictionResponse', (_message.Message,), {
  'DESCRIPTOR' : _ABORTPREDICTIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.prediction.v1.prediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.prediction.v1.AbortPredictionResponse)
  })
_sym_db.RegisterMessage(AbortPredictionResponse)


DESCRIPTOR._options = None
_LISTPREDICTIONSREQUEST_LABELSENTRY._options = None

_PREDICTIONSERVICE = _descriptor.ServiceDescriptor(
  name='PredictionService',
  full_name='github.com.metaprov.modelaapi.services.prediction.v1.PredictionService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1303,
  serialized_end=2891,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListPredictions',
    full_name='github.com.metaprov.modelaapi.services.prediction.v1.PredictionService.ListPredictions',
    index=0,
    containing_service=None,
    input_type=_LISTPREDICTIONSREQUEST,
    output_type=_LISTPREDICTIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002\021\022\017/v1/predictions',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreatePrediction',
    full_name='github.com.metaprov.modelaapi.services.prediction.v1.PredictionService.CreatePrediction',
    index=1,
    containing_service=None,
    input_type=_CREATEPREDICTIONREQUEST,
    output_type=_CREATEPREDICTIONRESPONSE,
    serialized_options=b'\202\323\344\223\002\024\"\017/v1/predictions:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetPrediction',
    full_name='github.com.metaprov.modelaapi.services.prediction.v1.PredictionService.GetPrediction',
    index=2,
    containing_service=None,
    input_type=_GETPREDICTIONREQUEST,
    output_type=_GETPREDICTIONRESPONSE,
    serialized_options=b'\202\323\344\223\002$\022\"/v1/{namespace}/predictions/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdatePrediction',
    full_name='github.com.metaprov.modelaapi.services.prediction.v1.PredictionService.UpdatePrediction',
    index=3,
    containing_service=None,
    input_type=_UPDATEPREDICTIONREQUEST,
    output_type=_UPDATEPREDICTIONRESPONSE,
    serialized_options=b'\202\323\344\223\002N\032I/v1/{prediction.metadata.namespace}predictions/{prediction.metadata.name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeletePrediction',
    full_name='github.com.metaprov.modelaapi.services.prediction.v1.PredictionService.DeletePrediction',
    index=4,
    containing_service=None,
    input_type=_DELETEPREDICTIONREQUEST,
    output_type=_DELETEPREDICTIONRESPONSE,
    serialized_options=b'\202\323\344\223\002\030*\026/v1/predictions/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Download',
    full_name='github.com.metaprov.modelaapi.services.prediction.v1.PredictionService.Download',
    index=5,
    containing_service=None,
    input_type=_DOWNLOADPREDICTIONREQUEST,
    output_type=_DOWNLOADPREDICTIONRESPONSE,
    serialized_options=b'\202\323\344\223\0027\0225/api/v1alpha1/{namespace}/predictions/{name}:download',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Abort',
    full_name='github.com.metaprov.modelaapi.services.prediction.v1.PredictionService.Abort',
    index=6,
    containing_service=None,
    input_type=_ABORTPREDICTIONREQUEST,
    output_type=_ABORTPREDICTIONRESPONSE,
    serialized_options=b'\202\323\344\223\0024\"2/api/v1alpha1/{namespace}/predictions/{name}:abort',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PREDICTIONSERVICE)

DESCRIPTOR.services_by_name['PredictionService'] = _PREDICTIONSERVICE

# @@protoc_insertion_point(module_scope)
